import 'package:flutter/material.dart';
import 'package:flutter_expandable_fab/flutter_expandable_fab.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:hub/commons/components/atoms/menu_button_item/widget.dart';
import 'package:hub/commons/components/molecules/menu_item/widget.dart';
import 'package:hub/commons/schema/enums/enums.dart';

import '/commons/widgets/flutter_flow_icon_button.dart';
import '/commons/widgets/flutter_flow_theme.dart';
import '/commons/widgets/flutter_flow_util.dart';
import 'model.dart';


class MenuListViewComponentWidget extends StatefulWidget {
  const MenuListViewComponentWidget({
    super.key,
    required this.changeMenuStyle,
    required this.registerVisitorOptAction,
    required this.scheduleVisitOptAction,
    required this.peopleOnThePropertyOptAction,
    required this.preferencesSettings,
    required this.liberationHistoryOptAction,
    required this.accessQRCodeOptAction,
    required this.expandable,
    required this.item,
    required this.options,
    required this.messageHistoryAction,
  });

  final bool expandable;
  final MenuItem item;

  final List<MenuEntry> options;
  final Future Function()? changeMenuStyle;
  final Future Function()? registerVisitorOptAction;
  final Future Function()? scheduleVisitOptAction;
  final Future Function()? peopleOnThePropertyOptAction;
  final Future Function()? preferencesSettings;
  final Future Function()? liberationHistoryOptAction;
  final Future Function()? accessQRCodeOptAction;
  final Future Function()? messageHistoryAction;

  @override
  State<MenuListViewComponentWidget> createState() =>
      _MenuListViewComponentWidgetState();
}

class _MenuListViewComponentWidgetState
    extends State<MenuListViewComponentWidget> {
  late MenuListViewComponentModel _model;

  @override
  void setState(VoidCallback callback) {
    super.setState(callback);
    _model.onUpdate();
  }

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => MenuListViewComponentModel());
  }

  @override
  void dispose() {
    _model.maybeDispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Wrap(
      spacing: 0.0,
      runSpacing: 0.0,
      alignment: WrapAlignment.start,
      crossAxisAlignment: WrapCrossAlignment.start,
      direction: Axis.horizontal,
      runAlignment: WrapAlignment.start,
      verticalDirection: VerticalDirection.down,
      clipBehavior: Clip.none,
      children: [
        buildMenuItem(context),
        if (widget.expandable)
        buildExpandableButton(context),
      ],
    );
  }

  Widget buildMenuItem(BuildContext context) {
      switch(widget.item) {
      case MenuItem.button:
        return SizedBox(
          height: 100,
          width: double.infinity,
            child: ListView.builder(
              addAutomaticKeepAlives: true,
              padding: EdgeInsets.zero,
              shrinkWrap: true,
              physics: const AlwaysScrollableScrollPhysics(),
              scrollDirection: Axis.horizontal,
              
              itemCount: widget.options.length,
              itemBuilder: (context, index) {
                return SizedBox(
                  height: 115,
                  width: 115,
                  child: widget.options[index]);
              },
            ),
        );
      case MenuItem.card:
        return ListView.builder(
          addAutomaticKeepAlives: true,
          padding: EdgeInsets.zero,
          shrinkWrap: true,
          physics: const AlwaysScrollableScrollPhysics(),
          itemCount: widget.options.length,
          itemBuilder: (context, index) {
          return MenuButtonWidget(
            action: widget.registerVisitorOptAction,
            title: FFLocalizations.of(context).getVariableText(
              enText: 'Register Visitor',
              ptText: 'Registrar Visitante',
            ),
            icon: Icons.person_add_alt_1_outlined,
          );
          },
        );
  }
}

  Row buildExpandableButton(BuildContext context) {
    return Row(
        mainAxisSize: MainAxisSize.max,
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Text(
            FFLocalizations.of(context).getVariableText(
              enText: 'Expand',
              ptText: 'Expandir',
            ),
            style: FlutterFlowTheme.of(context).title1.override(
              fontFamily: 'Nunito',
              color: FlutterFlowTheme.of(context).primaryText,
              fontSize: 12.0,
              fontWeight: FontWeight.w600,
              fontStyle: FontStyle.normal,
            ),
          ),
          Align(
            alignment: const AlignmentDirectional(0.0, 0.0),
            child: FlutterFlowIconButton(
              borderColor: Colors.transparent,
              borderRadius: 20.0,
              borderWidth: 0.0,
              buttonSize: 50.0,
              fillColor: const Color(0x00FFFFFF),
              icon: Icon(
                Icons.keyboard_arrow_down_outlined,
                color: FlutterFlowTheme.of(context).primary,
              ),
              onPressed: () async {
                await widget.changeMenuStyle?.call();
              },
            ),
          ),
        ],
      );
  }
}
